#!/bin/bash
#
# Maintenance script for log archiving

SCRIPTPATH=$(dirname $(readlink -f $0))

# Default configuration settings
COMPRESSOR=gzip
MAXAGE=30

if [ -f "${SCRIPTPATH}standalone.conf" ]; then
        . "${SCRIPTPATH}standalone.conf"
fi

# Try to automatically get all needed information
JBOSS_HOME=$(dirname ${SCRIPTPATH})
printf "JBOSS_HOME = ${JBOSS_HOME}\n"

if [ ! -f ${JBOSS_HOME}/standalone/configuration/standalone-full.xml ]; then
        # something went terribly wrong...
        exit 0
fi

BASEPATH=${JBOSS_HOME}/standalone/log
BASENAME="boot.log server.log"

printf "PROCEEDING ...\n"

if [ -n "${COMPRESSOR}" ] && which ${COMPRESSOR} > /dev/null 2> /dev/null; then
        case "${COMPRESSOR}" in
        gzip)   COMPEXT=gz;;
        bzip2)  COMPEXT=bz2;;
        *)      COMPRESSOR=gzip; COMPEXT=gz;;   # should never happen
        esac

        # compress all old log files
        for BASEFILE in ${BASENAME}; do
                if [ -h ${BASEPATH}/${BASEFILE} ]; then
                        # it's a symbolic link. Lets detect the target
                        CURRENTLOG="$(basename $(readlink ${BASEPATH}/${BASEFILE}))"
                else
                        CURRENTLOG=""
                fi
                for LOGFILE in $(find ${BASEPATH} -type f -name ${BASEFILE}'.????-??-??'); do
                        if [ "${CURRENTLOG}" != "$(basename ${LOGFILE})" ]; then
                                # ok - we can compress it
                                ${COMPRESSOR} ${LOGFILE}
                        fi
                done
        done
fi

if [ ${MAXAGE} -gt 2 ]; then
        # kill all files older than MAXAGE days
        for BASEFILE in ${BASENAME}; do
                find ${BASEPATH} -type f  -name ${BASEFILE}'.????-??-??' -mtime +${MAXAGE} -exec rm -f {} \;
                find ${BASEPATH} -type f  -name ${BASEFILE}'.????-??-??.'${COMPEXT} -mtime +${MAXAGE} -exec rm -f {} \;
        done
fi

