#!/bin/bash
#
# This script performs a housekeeping-restart of
# the jtel ACD Web Server.

SCRIPTPATH=$(dirname $(readlink -f $0))

# default: no autoupdate
AUTOUPDATE_LOCATION=

if [ -f "${SCRIPTPATH}standalone.conf" ]; then
        . "${SCRIPTPATH}standalone.conf"
fi

# Try to automatically get all needed information
JBOSS_HOME=$(dirname ${SCRIPTPATH})

printf "JBOSS_HOME=${JBOSS_HOME}\n"

if [ ! -f ${JBOSS_HOME}/standalone/configuration/standalone-full.xml ]; then
        # something went terribly wrong....
        exit 0
fi

printf "PROCEEDING ...\n"

JBOSS_UID=$(stat -c '%U' ${JBOSS_HOME}/standalone/configuration)
JBOSS_GID=$(stat -c '%G' ${JBOSS_HOME}/standalone/configuration)

printf "JBOSS_UID=${JBOSS_UID}\n"
printf "JBOSS_GID=${JBOSS_GID}\n"

startlog() {
        rm -f ${JBOSS_HOME}/standalone/log/restart.log
        touch ${JBOSS_HOME}/standalone/log/restart.log
}

logmessage() {
        echo "$(date "+%F %T") $@" >> ${JBOSS_HOME}/standalone/log/restart.log
	printf "$(date "+%F %T") $@\n"
}

test_webserver() {
        for NETIF in /sys/class/net/*; do
                # Determine the primary IP Address of the interface
                LOCAL_IP="$(ip addr show $(basename $NETIF) | grep -m 1 inet | awk '{ print $2 }')"
                LOCAL_IP=${LOCAL_IP%%/*}

                logmessage "Testing web server on ${LOCAL_IP} via $(basename $NETIF)"
                RET=$(wget --no-proxy --timeout=60 -q -O - "http://${LOCAL_IP}:8080/CarrierPortal/sysadmin/login" | grep remove-group-member.icepush.txt.xhtml 2>/dev/null | grep -c remove-group-member.icepush.txt.xhtml)
                if [ $RET -gt 0 ]; then
                        return 0
                fi
        done
        return 1
}

startlog
logmessage "Initiating jtel ACD web server restart sequence..."

# stop jboss
logmessage "Stop web server"
service wildfly stop 1>/dev/null 2>/dev/null

# small pause...
sleep 2

# automatically update binaries...
if [ -n "${AUTOUPDATE_LOCATION}" -a -f "${AUTOUPDATE_LOCATION}/CarrierPortal.war" ]; then
        logmessage "Trying to update from ${AUTOUPDATE_LOCATION}"
        # get software from repository
        rsync -ac ${AUTOUPDATE_LOCATION}/*ar ${JBOSS_HOME}/standalone/deployments 1>/dev/null 2>/dev/null
        # fix ownership and file mode
        chown ${JBOSS_UID}:${JBOSS_GID} ${JBOSS_HOME}/standalone/deployments/* 1>/dev/null 2>/dev/null
        chmod 644 ${JBOSS_HOME}/standalone/deployments/* 1>/dev/null 2>/dev/null
fi

# start jboss
logmessage "Start web server"
service wildfly start 1>/dev/null 2>/dev/null

# wait for service to come up
sleep 60

logmessage "Ready to test web server"

# retry loop
while ! test_webserver; do

        # something went wrong - retry
        logmessage "FAILED: Restarting web server"
        # stop
        service wildfly stop #1>/dev/null 2>/dev/null
        # small pause...
        sleep 5
        # start
        service wildfly start #1>/dev/null 2>/dev/null
        # wait for service to come up
        sleep 300
done

logmessage "SUCCESS - web server running"

